@@ -12,15 +12,19 @@
 
    Copyright 2022, HSPyLib team
 """
-from typing import Optional
-
 from hspylib.core.config.app_config import AppConfigs
+from typing import Optional
 
 
 class DBConfiguration(AppConfigs):
-    """TODO"""
+    """Holds database configurations."""
+
+    def __init__(
+        self,
+        resource_dir: str,
+        filename: str | None = None,
+        profile: str | None = None):
 
-    def __init__(self, resource_dir: str, filename: Optional[str] = None, profile: Optional[str] = None):
         super().__init__(resource_dir, filename, profile)
         self._hostname = self["datasource.hostname"]
         self._port = self.get_int("datasource.port")
